from microbit import *

#Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi vestibulum eu sapien commodo posuere. Nunc cursus justo non sem elementum, id finibus erat porta. Ut aliquam vestibulum urna ornare porta. Praesent laoreet iaculis erat, bibendum semper tellus blandit quis. Vivamus vitae tellus vel quam elementum porta. Morbi neque lorem, condimentum id blandit vel, ultrices at urna. Sed nec malesuada risus, nec tincidunt ante. Curabitur vel purus porttitor, hendrerit odio eu, dictum libero. Quisque non elit sodales, facilisis nisl vel, mollis mauris. Vestibulum placerat id diam id malesuada. Mauris nunc nisl, vehicula vel quam sed, finibus iaculis purus. Nunc at ullamcorper ex. Vivamus vel vestibulum dui. Proin luctus vehicula nisl. Aenean ultricies id quam nec consequat.
#Quisque consequat non metus a efficitur. Aliquam eu luctus nulla. Vestibulum pellentesque elit vitae quam condimentum suscipit. Nullam maximus porttitor gravida. Quisque imperdiet orci vitae urna volutpat, ac condimentum arcu tempus. Nullam feugiat feugiat magna, eu sagittis libero rutrum sit amet. Pellentesque ut augue turpis. Nullam sed massa eget velit placerat sagittis. Etiam euismod augue nibh, volutpat convallis enim porttitor ut. Nullam non mi sagittis lectus rhoncus ultricies. Nulla tempus tortor eu lectus mollis pellentesque. In porta convallis lorem, at interdum eros blandit at. Integer in nunc ut velit aliquam scelerisque. Duis lacinia, enim porttitor hendrerit viverra, nibh urna tempor enim, id vestibulum nisl nisl a purus. Ut id tincidunt sapien. Fusce non ante justo.
#Duis in neque tristique, sollicitudin lorem et, condimentum ligula. Nullam in euismod tortor. Ut sed purus tristique, maximus augue non, placerat dolor. Praesent tincidunt libero felis, convallis venenatis dui blandit quis. Mauris nulla odio, commodo in ex ut, bibendum congue sem. Curabitur sed enim lectus. Nam justo est, maximus et commodo ac, laoreet eu nunc. Donec interdum tortor maximus vestibulum fringilla. Aenean nec sapien imperdiet, elementum odio quis, pharetra urna. Nunc varius imperdiet eleifend. Sed eget aliquet quam.
#In porttitor diam tortor, ut aliquam neque rhoncus aliquet. Proin odio nisi, gravida et orci ac, dignissim efficitur ligula. Nulla facilisi. Proin ut libero dolor. Sed risus lectus, cursus in nibh id, convallis malesuada risus. Maecenas vitae gravida est, et condimentum ligula. In tortor felis, venenatis ac laoreet sit amet, posuere finibus ante. Nulla magna arcu, interdum id tortor et, fringilla vehicula nibh. Integer sed velit quis nibh hendrerit fermentum ac vitae tellus.
#Praesent augue erat, cursus non pellentesque nec, porta nec elit. Nam faucibus augue vitae augue aliquet mattis. Sed laoreet quam non aliquet fringilla. Maecenas dapibus vestibulum sem, vel rhoncus sem rhoncus eu. Nam facilisis ante mauris, eget rutrum risus mollis id. Fusce scelerisque nisi dapibus, ullamcorper magna ut, suscipit lorem. Donec posuere ante egestas, sagittis eros a, gravida est. Donec congue sit amet orci non mattis. Phasellus ac neque ac leo volutpat efficitur et ut ex. Donec sit amet neque quis risus accumsan volutpat vel ac elit. Nam interdum ligula ac dapibus dignissim. Aliquam luctus venenatis volutpat. Sed et mi ac nisi iaculis imperdiet. Nulla velit eros, sollicitudin sit amet porttitor a, tincidunt et nisl. Morbi eros ante, elementum vitae arcu nec, malesuada fringilla urna. Sed at tempor turpis.
#Praesent id lacinia leo. Duis tincidunt tortor id velit dictum, id vehicula velit blandit. Nunc lectus mi, condimentum non convallis ac, laoreet eget mauris. Ut efficitur nibh ac ex faucibus euismod. Nam ultrices justo sed magna egestas, id sollicitudin sem accumsan. Proin at ligula urna. Praesent at iaculis metus, ut posuere quam. Vestibulum eleifend massa tellus. Vivamus suscipit nisi in leo eleifend, vitae condimentum velit dictum. In eleifend purus at congue rutrum. Praesent dictum tortor et erat mollis, quis bibendum sem tincidunt. Proin vulputate pharetra nulla, in maximus nibh condimentum at. Ut ultricies ipsum nec arcu tempor, sed volutpat justo egestas.
#Donec interdum feugiat est quis laoreet. Donec sed justo non odio sollicitudin pulvinar hendrerit eu risus. Aliquam viverra dui scelerisque dui rhoncus, sit amet pharetra elit lobortis. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Suspendisse accumsan, nibh at fringilla rutrum, sem lacus suscipit neque, eget auctor lectus mauris vitae sapien. Integer nec felis a tortor interdum tempor non id odio. Integer tellus ipsum, facilisis nec vulputate eu, mollis ut neque. Nullam eget risus ornare, maximus sem sit amet, pretium dolor. Cras venenatis ultricies sapien, ut malesuada libero imperdiet id. Morbi enim lectus, tincidunt sed lectus in, pulvinar faucibus ante. Cras et aliquam mauris. Fusce sodales dui eu augue malesuada lobortis. Suspendisse potenti. Quisque porttitor scelerisque blandit.
#Quisque volutpat augue nisi, sed elementum nibh porttitor ut. Phasellus tincidunt suscipit arcu at molestie. Mauris convallis feugiat erat. Praesent fringilla mauris velit, quis sagittis lorem tristique non. Duis eu magna odio. Nam nec ante nec nisl commodo interdum placerat et orci. In et urna et velit commodo vehicula. Cras sed nisi accumsan, scelerisque tellus condimentum, consectetur nisi.

"""
Donec at dictum dolor. Nam eu neque nisi. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Nunc vitae feugiat dolor. Phasellus maximus, lacus quis posuere ornare, quam nisi sollicitudin velit, vitae tristique elit velit quis nisl. Nullam non bibendum tortor. Vivamus semper et metus vel sagittis. Ut lacinia maximus est, luctus sollicitudin eros blandit non. Morbi finibus vulputate lacus, sed interdum lectus laoreet sed. Donec fringilla nec lectus eget blandit. Aenean a imperdiet odio, in eleifend metus. Pellentesque at imperdiet magna, quis suscipit ante. Pellentesque facilisis sagittis dictum. Nunc in enim in lorem porta viverra. Nam vestibulum finibus felis, vitae lobortis lorem vestibulum id.
Donec eu efficitur mauris. Pellentesque tincidunt id leo eu blandit. Ut ac consequat purus. Integer egestas leo ac convallis consectetur. Nulla posuere turpis eu turpis feugiat blandit. Aliquam ut congue ex. Vivamus dapibus tincidunt libero ac lacinia. Aenean arcu mi, faucibus dapibus nunc vel, tincidunt semper nulla. Etiam nec ipsum eu eros fermentum mollis a eu justo. Pellentesque pulvinar, neque nec sodales elementum, tellus nulla molestie sapien, sit amet venenatis urna mi eu tellus. Curabitur nec eleifend ante.
Vivamus sapien massa, aliquet vitae libero vel, gravida vestibulum risus. Ut ac nisi non augue hendrerit ornare. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Maecenas non sem interdum nibh posuere ullamcorper eu sagittis dolor. Vivamus posuere diam non augue feugiat, ac vulputate turpis condimentum. Sed pulvinar magna mauris, ac gravida tellus dignissim quis. Etiam ut placerat arcu.
Nunc in ipsum diam. Donec gravida, nibh vel pellentesque pulvinar, nunc leo ultrices libero, non porta diam tellus quis odio. Cras aliquet, enim vitae vulputate hendrerit, urna augue euismod odio, sit amet pretium nisl urna vel dolor. In tristique sapien mauris, ac vulputate magna ornare nec. Donec rhoncus magna in orci porta feugiat. Cras nibh turpis, consectetur in nunc in, varius pretium libero. Proin eget orci feugiat, auctor libero sit amet, imperdiet ex. Cras tincidunt dapibus nunc, at aliquet mi volutpat ut.
Aliquam erat volutpat. Cras vel laoreet ipsum, vitae cursus libero. Integer mollis pulvinar lorem, vel pretium nulla maximus id. Suspendisse sagittis tortor ligula, suscipit imperdiet tortor rutrum et. Ut turpis ante, pellentesque vitae nisl at, consectetur ornare velit. Phasellus nisi lacus, iaculis id feugiat sit amet, commodo ut ex. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Integer facilisis dignissim mi metus. 
"""
)
def show_num(num):
    if 1 + 1 == 2 and 2 + 2 == 4 or 3 + 3 == 6 \
       and 3 - 3 == 0 and 'this is nonsense' == 'this is nonsense':
        print('Hello')
        text = """
		This should survive
		""" # This shouldn't
    i = Image()
    i.fill(0)
    if num & 0b00001000:
        i.set_pixel(0, 2, 9)
    if num & 0b00000100:
        i.set_pixel(1, 2, 9)
    if num & 0b00000010:
        i.set_pixel(2, 2, 9) # A comment on a line
    if num & 0b00000001:
        i.set_pixel(3, 2, 9)
    display.show(i)

show_num(12)
